==> defi-services-lib-1.0.4.tar.gz: defi-services-lib-1.0.4/src/defi_services/lending_pools/lending_pools_info/polygon/aave_v2_polygon.py <==
AAVE_V2_POLYGON = {
    "address": "0x8dFf5E27EA6b7AC08EbFdf9eB090F32ee9a30fcf",
    "name": "Aave V2 Lending Pool",
    "rewardToken": "0xD6DF932A45C0f255f85145f286eA0b292B21C90B",
    "stakedIncentiveAddress": '0x2C901a65071c077C78209b06AB2b5D8eC285aB84',
    "oracleAddress": "0x0229F777B0fAb107F9591a41d5F02E4e98dB6f2d",
    "type": "LENDING_POOL",
    "reservesList": {
        "0x8f3cf7ad23cd3cadbd9735aff958023239c6a063": {
            "tToken": "0x27f8d03b3a2196956ed754badc28d73be8830a6e",
            "dToken": "0x75c4d1fb84429023170086f06e682dcbbf537b7d",
            "sdToken": "0x2238101b7014c279aaf6b408a284e49cdbd5db55",
            "liquidationThreshold": 0.8
        },
        "0x2791bca1f2de4661ed88a30c99a7a9449aa84174": {
            "tToken": "0x1a13f4ca1d028320a707d99520abfefca3998b7f",
            "dToken": "0x248960a9d75edfa3de94f7193eae3161eb349a12",
            "sdToken": "0xdeb05676db0db85cecafe8933c903466bf20c572",
            "liquidationThreshold": 0.85
        },
        "0xc2132d05d31c914a87c6611c10748aeb04b58e8f": {
            "tToken": "0x60d55f02a771d515e077c9c2403a1ef324885cec",
            "dToken": "0x8038857fd47108a07d1f6bf652ef1cbec279a2f3",
            "sdToken": "0xe590cfca10e81fed9b0e4496381f02256f5d2f61",
            "liquidationThreshold": 0.0
        },
        "0x1bfd67037b42cf73acf2047067bd4f2c47d9bfd6": {
            "tToken": "0x5c2ed810328349100a66b82b78a1791b101c9d61",
            "dToken": "0xf664f50631a6f0d72ecdaa0e49b0c019fa72a8dc",
            "sdToken": "0x2551b15db740db8348bfadfe06830210ec2c2f13",
            "liquidationThreshold": 0.75
        },
        "0x7ceb23fd6bc0add59e62ac25578270cff1b9f619": {
            "tToken": "0x28424507fefb6f7f8e9d3860f56504e4e5f5f390",
            "dToken": "0xede17e9d79fc6f9ff9250d9eefbdb88cc18038b5",
            "sdToken": "0xc478cbbeb590c76b01ce658f8c4dda04f30e2c6f",
            "liquidationThreshold": 0.825
        },
        "0x0d500b1d8e8ef31e21c99d1db9a6444d3adf1270": {
            "tToken": "0x8df3aad3a84da6b69a4da8aec3ea40d9091b2ac4",
            "dToken": "0x59e8e9100cbfcbcbadf86b9279fa61526bbb8765",
            "sdToken": "0xb9a6e29fb540c5f1243ef643eb39b0acbc2e68e3",
            "liquidationThreshold": 0.7
        },
        "0xd6df932a45c0f255f85145f286ea0b292b21c90b": {
            "tToken": "0x1d2a0e5ec8e5bbdca5cb219e649b565d8e5c3360",
            "dToken": "0x1c313e9d0d826662f5ce692134d938656f681350",
            "sdToken": "0x17912140e780b29ba01381f088f21e8d75f954f9",
            "liquidationThreshold": 0.65
        },
        "0x385eeac5cb85a38a9a07a70c73e0a3271cfb54a7": {
            "tToken": "0x080b5bf8f360f624628e0fb961f4e67c9e3c7cf1",
            "dToken": "0x36e988a38542c3482013bb54ee46ac1fb1efedcd",
            "sdToken": "0x6a01db46ae51b19a6b85be38f1aa102d8735d05b",
            "liquidationThreshold": 0.4
        },
        "0x9a71012b13ca4d3d0cdc72a177df3ef03b0e76a3": {
            "tToken": "0xc4195d4060daeac44058ed668aa5efec50d77ff6",
            "dToken": "0x773e0e32e7b6a00b7ca9daa85dfba9d61b7f2574",
            "sdToken": "0xbc30bbe0472e0e86b6f395f9876b950a13b23923",
            "liquidationThreshold": 0.45
        },
        "0x85955046df4668e1dd369d2de9f3aeb98dd2a369": {
            "tToken": "0x81fb82aacb4abe262fc57f06fd4c1d2de347d7b1",
            "dToken": "0x43150aa0b7e19293d935a412c8607f9172d3d3f3",
            "sdToken": "0xa742710c0244a8ebcf533368e3f0b956b6e53f7b",
            "liquidationThreshold": 0.45
        },
        "0x172370d5cd63279efa6d502dab29171933a610af": {
            "tToken": "0x3df8f92b7e798820ddcca2ebea7babda2c90c4ad",
            "dToken": "0x780bbcbcda2cdb0d2c61fd9bc68c9046b18f3229",
            "sdToken": "0x807c97744e6c9452e7c2914d78f49d171a9974a0",
            "liquidationThreshold": 0.45
        },
        "0x0b3f868e0be5597d5db7feb59e1cadbb0fdda50a": {
            "tToken": "0x21ec9431b5b55c5339eb1ae7582763087f98fac2",
            "dToken": "0x9cb9feafa73bf392c905eebf5669ad3d073c3dfc",
            "sdToken": "0x7ed588dcb30ea11a54d8a5e9645960262a97cd54",
            "liquidationThreshold": 0.45
        },
        "0x53e0bca35ec356bd5dddfebbd1fc0fd03fabad39": {
            "tToken": "0x0ca2e42e8c21954af73bc9af1213e4e81d6a669a",
            "dToken": "0xcc71e4a38c974e19bdbc6c0c19b63b8520b1bb09",
            "sdToken": "0x9fb7f546e60ddfaa242caef146fa2f4172088117",
            "liquidationThreshold": 0.65
        }
    }
}

==> defi-services-lib-1.0.5.tar.gz: defi-services-lib-1.0.5/src/defi_services/lending_pools/lending_pools_info/polygon/aave_v2_polygon.py <==
AAVE_V2_POLYGON = {
    "address": "0x8dff5e27ea6b7ac08ebfdf9eb090f32ee9a30fcf",
    "name": "Aave V2 Lending Pool",
    "rewardToken": "0xd6df932a45c0f255f85145f286ea0b292b21c90b",
    "stakedIncentiveAddress": '0x2c901a65071c077c78209b06ab2b5d8ec285ab84',
    "oracleAddress": "0x0229f777b0fab107f9591a41d5f02e4e98db6f2d",
    "type": "LENDING_POOL",
    "reservesList": {
        "0x8f3cf7ad23cd3cadbd9735aff958023239c6a063": {
            "tToken": "0x27f8d03b3a2196956ed754badc28d73be8830a6e",
            "dToken": "0x75c4d1fb84429023170086f06e682dcbbf537b7d",
            "sdToken": "0x2238101b7014c279aaf6b408a284e49cdbd5db55",
            "liquidationThreshold": 0.8
        },
        "0x2791bca1f2de4661ed88a30c99a7a9449aa84174": {
            "tToken": "0x1a13f4ca1d028320a707d99520abfefca3998b7f",
            "dToken": "0x248960a9d75edfa3de94f7193eae3161eb349a12",
            "sdToken": "0xdeb05676db0db85cecafe8933c903466bf20c572",
            "liquidationThreshold": 0.85
        },
        "0xc2132d05d31c914a87c6611c10748aeb04b58e8f": {
            "tToken": "0x60d55f02a771d515e077c9c2403a1ef324885cec",
            "dToken": "0x8038857fd47108a07d1f6bf652ef1cbec279a2f3",
            "sdToken": "0xe590cfca10e81fed9b0e4496381f02256f5d2f61",
            "liquidationThreshold": 0.0
        },
        "0x1bfd67037b42cf73acf2047067bd4f2c47d9bfd6": {
            "tToken": "0x5c2ed810328349100a66b82b78a1791b101c9d61",
            "dToken": "0xf664f50631a6f0d72ecdaa0e49b0c019fa72a8dc",
            "sdToken": "0x2551b15db740db8348bfadfe06830210ec2c2f13",
            "liquidationThreshold": 0.75
        },
        "0x7ceb23fd6bc0add59e62ac25578270cff1b9f619": {
            "tToken": "0x28424507fefb6f7f8e9d3860f56504e4e5f5f390",
            "dToken": "0xede17e9d79fc6f9ff9250d9eefbdb88cc18038b5",
            "sdToken": "0xc478cbbeb590c76b01ce658f8c4dda04f30e2c6f",
            "liquidationThreshold": 0.825
        },
        "0x0d500b1d8e8ef31e21c99d1db9a6444d3adf1270": {
            "tToken": "0x8df3aad3a84da6b69a4da8aec3ea40d9091b2ac4",
            "dToken": "0x59e8e9100cbfcbcbadf86b9279fa61526bbb8765",
            "sdToken": "0xb9a6e29fb540c5f1243ef643eb39b0acbc2e68e3",
            "liquidationThreshold": 0.7
        },
        "0xd6df932a45c0f255f85145f286ea0b292b21c90b": {
            "tToken": "0x1d2a0e5ec8e5bbdca5cb219e649b565d8e5c3360",
            "dToken": "0x1c313e9d0d826662f5ce692134d938656f681350",
            "sdToken": "0x17912140e780b29ba01381f088f21e8d75f954f9",
            "liquidationThreshold": 0.65
        },
        "0x385eeac5cb85a38a9a07a70c73e0a3271cfb54a7": {
            "tToken": "0x080b5bf8f360f624628e0fb961f4e67c9e3c7cf1",
            "dToken": "0x36e988a38542c3482013bb54ee46ac1fb1efedcd",
            "sdToken": "0x6a01db46ae51b19a6b85be38f1aa102d8735d05b",
            "liquidationThreshold": 0.4
        },
        "0x9a71012b13ca4d3d0cdc72a177df3ef03b0e76a3": {
            "tToken": "0xc4195d4060daeac44058ed668aa5efec50d77ff6",
            "dToken": "0x773e0e32e7b6a00b7ca9daa85dfba9d61b7f2574",
            "sdToken": "0xbc30bbe0472e0e86b6f395f9876b950a13b23923",
            "liquidationThreshold": 0.45
        },
        "0x85955046df4668e1dd369d2de9f3aeb98dd2a369": {
            "tToken": "0x81fb82aacb4abe262fc57f06fd4c1d2de347d7b1",
            "dToken": "0x43150aa0b7e19293d935a412c8607f9172d3d3f3",
            "sdToken": "0xa742710c0244a8ebcf533368e3f0b956b6e53f7b",
            "liquidationThreshold": 0.45
        },
        "0x172370d5cd63279efa6d502dab29171933a610af": {
            "tToken": "0x3df8f92b7e798820ddcca2ebea7babda2c90c4ad",
            "dToken": "0x780bbcbcda2cdb0d2c61fd9bc68c9046b18f3229",
            "sdToken": "0x807c97744e6c9452e7c2914d78f49d171a9974a0",
            "liquidationThreshold": 0.45
        },
        "0x0b3f868e0be5597d5db7feb59e1cadbb0fdda50a": {
            "tToken": "0x21ec9431b5b55c5339eb1ae7582763087f98fac2",
            "dToken": "0x9cb9feafa73bf392c905eebf5669ad3d073c3dfc",
            "sdToken": "0x7ed588dcb30ea11a54d8a5e9645960262a97cd54",
            "liquidationThreshold": 0.45
        },
        "0x53e0bca35ec356bd5dddfebbd1fc0fd03fabad39": {
            "tToken": "0x0ca2e42e8c21954af73bc9af1213e4e81d6a669a",
            "dToken": "0xcc71e4a38c974e19bdbc6c0c19b63b8520b1bb09",
            "sdToken": "0x9fb7f546e60ddfaa242caef146fa2f4172088117",
            "liquidationThreshold": 0.65
        }
    }
}
